==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Chip.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ChipVariant_$type } from "./ChipVariant";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
/**
 * @hidden
 */
export let Chip = /*@__PURE__*/ (() => {
    class Chip extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.k = null;
            this.remove = null;
            this.select = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.e.n = this.k;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get g() {
            let ret_ = this.f.m("disabled");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.u("disabled", value_);
        }
        get h() {
            let ret_ = this.f.m("removable");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.u("removable", value_);
        }
        get i() {
            let ret_ = this.f.m("selectable");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.u("selectable", value_);
        }
        get j() {
            let ret_ = this.f.m("selected");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.u("selected", value_);
        }
        get a() {
            let ret_ = this.f.m("variant");
            ret_ = enumGetBox(ChipVariant_$type, EnumUtil.getEnumValue(ChipVariant_$type, this.f.f(ChipVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ChipVariant_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ChipVariant_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("variant", value_);
        }
        get d() {
            let ret_ = this.f.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set d(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("size", value_);
        }
        removeChanged() {
            if (this.remove != null) {
                this.f.q("remove", (a) => this.remove(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.t("remove");
            }
        }
        selectChanged() {
            if (this.select != null) {
                this.f.q("select", (a) => this.select(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.t("select");
            }
        }
    }
    Chip.$t = /*@__PURE__*/ markType(Chip, 'Chip', BaseElement.$);
    return Chip;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Chip.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ChipVariant_$type } from "./ChipVariant";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
/**
 * @hidden
 */
export let Chip = /*@__PURE__*/ (() => {
    class Chip extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.k = null;
            this.remove = null;
            this.select = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.e.o = this.k;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get g() {
            let ret_ = this.f.n("disabled");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.v("disabled", value_);
        }
        get h() {
            let ret_ = this.f.n("removable");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.v("removable", value_);
        }
        get i() {
            let ret_ = this.f.n("selectable");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.v("selectable", value_);
        }
        get j() {
            let ret_ = this.f.n("selected");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.v("selected", value_);
        }
        get a() {
            let ret_ = this.f.n("variant");
            ret_ = enumGetBox(ChipVariant_$type, EnumUtil.getEnumValue(ChipVariant_$type, this.f.f(ChipVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ChipVariant_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ChipVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("variant", value_);
        }
        get d() {
            let ret_ = this.f.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set d(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("size", value_);
        }
        removeChanged() {
            if (this.remove != null) {
                this.f.r("remove", (a) => this.remove(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("remove");
            }
        }
        selectChanged() {
            if (this.select != null) {
                this.f.r("select", (a) => this.select(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("select");
            }
        }
    }
    Chip.$t = /*@__PURE__*/ markType(Chip, 'Chip', BaseElement.$);
    return Chip;
})();
